@@ -4,21 +4,21 @@ context("Test support functions")
 
 
 test_that("Find Airport", {
-  expect_output(print(findAirport("ATL")[2]), "30397")
+  expect_output(print(find_airport("ATL")[[2]]), "30397")
 })
 
 test_that("Find Carrier", {
-  expect_output(print(findCarrier("United Air Lines")[1]), "UA")
+  expect_output(print(find_carrier("United Air Lines")[[1]]), "UA")
 })
 
 test_that("From To function", {
-  test <- make.netDir(OD_Sample)
-  expect_output(print(fromto.stat(test$gDir, "JFK", orig = "from")), "78")
+  test <- make_net_dir(OD_Sample)
+  expect_output(print(from_to_stats(test$gDir, "JFK", orig = "from")), "78")
 })
 
 
 test_that("boot_network", {
-  test <- make.netDir(OD_Sample)
+  test <- make_net_dir(OD_Sample)
   expect_length(boot_network(test$gDir, n = 10), 4)
   expect_gt(sum(boot_network(test$gDir, n = 10)), 0)
 })
